@@ -1,5 +1,5 @@
 rtex <- function(filename, pdf=FALSE) {
-  library(R.rsp);
+  require("R.rsp") || stop("Package not loaded: R.rsp");
   name <- gsub("[.][^.]*$", "", filename);
   ofile <- sprintf("%s.tex", name);
   sourceRsp(filename, response=FileRspResponse(ofile, overwrite=TRUE));
@@ -7,5 +7,5 @@ rtex <- function(filename, pdf=FALSE) {
   system(sprintf("dvips %s.dvi", name));
   if (pdf)
     system(sprintf("ps2pdf %s.ps", name));
-}
+} # rtex()
 
